@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_sync.c,v 1.24 2004/05/21 18:23:50 evertonm Exp $
+  $Id: ruli_sync.c,v 1.25 2004/06/16 17:28:44 evertonm Exp $
  */
 
 
@@ -30,8 +30,8 @@ Boston, MA 02111-1307, USA.
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <oop.h>
 
+#include <ruli_oop.h>
 #include <ruli_sync.h>
 #include <ruli_txt.h>
 #include <ruli_mem.h>
